package com.ccwangluo.im;

import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;

import com.ccwangluo.ccim.CCIMClient;
import com.ccwangluo.ccim.listener.OnConnectListener;
import com.ccwangluo.ccim.listener.ResultCallback;
import com.ccwangluo.ccim.listener.ResultEventCallback;
import com.ccwangluo.ccim.util.HmacUtil;
import com.ccwangluo.im.databinding.FragmentFirstBinding;

import java.util.ArrayList;
import java.util.List;

import ccim.protocol.Chat;
import ccim.protocol.Message;

public class FirstFragment extends Fragment {

    private FragmentFirstBinding binding;
    private static final String TAG = FirstFragment.class.getName();

    @Override
    public View onCreateView(
            LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState
    ) {

        binding = FragmentFirstBinding.inflate(inflater, container, false);
        return binding.getRoot();
    }

    public void onViewCreated(@NonNull View view, Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        String appKey = "c981adfde9c4000";
        String userName = "user100";
        Long userId = 100L;
        Long ts = System.currentTimeMillis();
        String data = appKey + "&" + userId + "&" + userName + "&" + ts +
                "&wW7cR31PwJseIoZMOs311nljHpwUmujs";

        String sign = HmacUtil.stringToSign("wW7cR31PwJseIoZMOs311nljHpwUmujs",data);

        CCIMClient.getInstance().initSDK(appKey, userName, 100L, ts, sign, new OnConnectListener() {
            @Override
            public void onSocketConnection() {
                refreshLogView("connect success");
            }

            @Override
            public void onSocketDisconnection() {
                refreshLogView("disconnect");
            }
        });
        CCIMClient.getInstance().registerMessageListener(new ResultEventCallback<Chat.ChatResponseMessage>() {
            @Override
            public void onSuccess(Chat.ChatResponseMessage chatResponseMessage) {
                refreshLogView(chatResponseMessage.toString());
            }
        });

        binding.getChatList.setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().getContactList(new ResultEventCallback<Chat.PullContactsResponse>() {
                    @Override
                    public void onSuccess(Chat.PullContactsResponse pullContactsResponse) {
                        List<Chat.PullContactsResponse.Channel> channelsList = pullContactsResponse.getChannelsList();
                        Log.d(TAG, "channelsList: " + channelsList.toString());
                        refreshLogView("channelsList: " + channelsList.toString());
                        List<Chat.PullContactsResponse.ContactGroup> contactGroupsList = pullContactsResponse.getContactGroupsList();
                        Log.d(TAG, "contactGroupsList: " + contactGroupsList.toString());
                        refreshLogView("contactGroupsList: " + contactGroupsList.toString());
                        List<Chat.PullContactsResponse.Contact> contactsList = pullContactsResponse.getContactsList();
                        Log.d(TAG, "contactsList: " + contactsList.toString());
                        refreshLogView("contactsList: " + contactsList.toString());
                    }
                });
            }
        });

        binding.getOfflineMessage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().getOfflineMessage(0L,new ResultEventCallback<List<Message.PullOfflineMessageResponse.OfflineMessage>>() {
                    @Override
                    public void onSuccess(List<Message.PullOfflineMessageResponse.OfflineMessage> offlineMessages) {
                        Log.d(TAG, "offlineMessages: " + offlineMessages.toString());
                        refreshLogView("offlineMessages: " + offlineMessages.toString());
                    }
                });
            }
        });

        binding.searchUser.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().searchUser("feng", new ResultEventCallback<List<Chat.SearchResponse.User>>() {
                    @Override
                    public void onSuccess(List<Chat.SearchResponse.User> users) {
                        Log.d(TAG, "onSuccess: " + users);
                        refreshLogView("searchUser: " + users);
                    }
                });
            }
        });

        binding.addUser.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().addContact(Long.parseLong(binding.userId.getText().toString()), new ResultEventCallback<Chat.AddContactResponse.AddResult>() {
                    @Override
                    public void onSuccess(Chat.AddContactResponse.AddResult addResult) {
                        refreshLogView("addUser : " + addResult.toString());
                    }
                });
            }
        });

        binding.sendTextMessage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().sendTextMessage("你好", Long.parseLong(binding.userId.getText().toString()), new ResultCallback() {
                    @Override
                    public void onSuccess() {
                        refreshLogView("sendTextMessage success");
                    }
                });
            }
        });

        binding.getContactRequests.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().getContactReqList(new ResultEventCallback<Chat.ContactRequestsResponse>() {
                    @Override
                    public void onSuccess(Chat.ContactRequestsResponse contactRequestsResponse) {
                        refreshLogView("getContactRequests: " + contactRequestsResponse.toString());
                    }
                });
            }
        });

        binding.checkContactRequests.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().checkContactReq(Long.parseLong(binding.userId.getText().toString()), true, new ResultCallback() {
                    @Override
                    public void onSuccess() {
                        refreshLogView("checkContactRequests success");
                    }
                });
            }
        });
        binding.createContactGroupRequest.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().createContactGroup("zhangsan", new ResultEventCallback<Chat.CreateContactGroupResponse>() {
                    @Override
                    public void onSuccess(Chat.CreateContactGroupResponse aLong) {
                        refreshLogView("createContactGroupRequest : " + aLong);
                    }
                });
            }
        });

//        binding.moveContactGroupRequest.setOnClickListener(new View.OnClickListener() {
//            @Override
//            public void onClick(View v) {
//                CCIMClient.getInstance().moveContactGroup(Long.parseLong(binding.groupId.getText().toString()), Long.parseLong(binding.userId.getText().toString()), new ResultCallback() {
//                    @Override
//                    public void onSuccess() {
//                        refreshLogView("moveContactGroupRequest success " );
//                    }
//                });
//            }
//        });

        binding.deleteContact.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().deleteContact(Long.parseLong(binding.userId.getText().toString()), new ResultCallback() {
                    @Override
                    public void onSuccess() {
                        refreshLogView("deleteContact success " );
                    }
                });
            }
        });

        binding.blockContact.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().blockContact(Long.parseLong(binding.userId.getText().toString()), true, new ResultCallback() {
                    @Override
                    public void onSuccess() {
                        refreshLogView("blockContact success " );
                    }
                });
            }
        });

        binding.reportIllegalUser.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().reportIllegalUser("搞黄色", "搞黄色", Long.parseLong(binding.userId.getText().toString()), new ResultCallback() {
                    @Override
                    public void onSuccess() {
                        refreshLogView("reportIllegalUser success " );
                    }
                });
            }
        });


        binding.sendChannelMessage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().sendChannelMessage("搞黄色", Long.parseLong(binding.channelId.getText().toString()), new ResultCallback() {
                    @Override
                    public void onSuccess() {
                        refreshLogView("sendChannelMessage success");
                    }
                });
            }
        });

        binding.startRecordAudioMessage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {

                CCIMClient.getInstance().startRecordAudioMessage(getActivity());
            }
        });
        binding.stopAndSendAudioMessage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().stopAndSendAudioMessage();
            }
        });

        binding.cancleAudioMessage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CCIMClient.getInstance().cancleAudioMessage();
            }
        });


    }

    public void refreshLogView(String msg) {
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            @Override
            public void run() {
                binding.txLog.append(msg);
                int offset = binding.txLog.getLineCount() * binding.txLog.getLineHeight();
                if (offset > binding.txLog.getHeight()) {
                    binding.txLog.scrollTo(0, offset - binding.txLog.getHeight() + binding.txLog.getLineHeight() * 2);
                }
            }
        });


    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        binding = null;
    }

}